==> irc-transport-0.1b-1.40.linux.tar.gz: irc-transport-0.1b-1.40/include/irctrans.h <==
#include <jabberd.h>
#define IRC_T_VERSION "0.9"
/* phase constants */
#define PR_NEW      0
#define PR_NOROOM   1
#define PR_INROOM   2
#define PR_SHUTDOWN 3
#define PS_NEW      4
#define PS_CONNECT  5
#define PS_NORMAL   6
#define PS_SHUTDOWN 7

typedef struct irctrans_data_st
{
    instance i;
    mtq q;
    xht sessions;
    xdbcache xc;
    xmlnode browse;
    xmlnode cfg;
    time_t start;
} _irctrans_data, *irctrans_data;
extern irctrans_data ircdata;


typedef struct irc_user_st {
    pool p;
    char *user;
    jid id;
    int ops;
    int voice;
    void *data;
} _user, *user;

typedef enum { chan_JOINING, chan_ACTIVE, chan_INACTIVE } chan_state;
typedef struct chan_struct {
    pool p;
    chan_state state;
    char *name;
    char *id;
    xht users;
    void *data;
} _chans, *chans;

typedef struct irc_sessions_struct
{
    pool p,pbuffer;
    mio m;
    char *id;
    jid j;
    int rc,default_session,phase,port;
    char *nick;
    jid nick_id;
    char *server,*buffer;
    xht channels;
    void *data;
    void *aux1;
    struct irc_sessions_struct *prev,*next;
} _irc_session, *irc_session;

void irc_parser(void *arg); /* main jpacket parser */

char *irc_get_server(pool p,char *input); 
char *irc_get_channel(pool p,char *input); 
char *irc_get_port(pool p,char *input);

void irc_parse_phase_zero(mio m, int flag, void *arg, char *buffer, int bufsz);
void irc_check_iq_get(mio m, int flag, void *arg, char *buffer, int bufsz);

void irc_strip_mirc_codes(char *input);
unsigned char *UTF8_to_str(pool p,unsigned char *in);
char *str_to_UTF8(pool p,unsigned char *in);

==> irc-transport-0.1.1-1.4.linux.tar.gz: irc-transport-0.1.1-1.40/include/irctrans.h <==
#include <jabberd.h>
#define IRC_T_VERSION "0.9"
/* phase constants */
#define PR_NEW      0
#define PR_NOROOM   1
#define PR_INROOM   2
#define PR_SHUTDOWN 3
#define PS_NEW      4
#define PS_CONNECT  5
#define PS_NORMAL   6
#define PS_SHUTDOWN 7

typedef struct irctrans_data_st
{
    instance i;
    mtq q;
    xht sessions;
    xdbcache xc;
    xmlnode browse;
    xmlnode cfg;
    time_t start;
} _irctrans_data, *irctrans_data;
extern irctrans_data ircdata;


typedef struct irc_user_st {
    pool p;
    char *user;
    jid id;
    int ops;
    int voice;
    void *data;
} _user, *user;

typedef enum { chan_JOINING, chan_ACTIVE, chan_INACTIVE } chan_state;
typedef struct chan_struct {
    pool p;
    chan_state state;
    char *name;
    char *id;
    xht users;
    void *data;
} _chans, *chans;

typedef struct irc_sessions_struct
{
    pool p,pbuffer;
    mio m;
    char *id;
    jid j;
    int rc,default_session,phase,port;
    char *nick;
    jid nick_id;
    char *server,*buffer;
    xht channels;
    void *data;
    void *aux1;
    struct irc_sessions_struct *prev,*next;
} _irc_session, *irc_session;

void irc_parser(void *arg); /* main jpacket parser */

char *irc_get_server(pool p, jid j,char *input); 
char *irc_get_channel(pool p,char *input); 
char *irc_get_port(pool p,char *input);

void irc_parse_phase_zero(mio m, int flag, void *arg, char *buffer, int bufsz);
void irc_parse_phase_one(mio m, int flag, void *arg, char *buffer, int bufsz);
void irc_check_iq_get(mio m, int flag, void *arg, char *buffer, int bufsz);
void irc_check_browse_get(mio m, int flag, void *arg, char *buffer, int bufsz);

void irc_strip_mirc_codes(char *input);
unsigned char *UTF8_to_str(pool p,unsigned char *in);
char *str_to_UTF8(pool p,unsigned char *in);
char *make_lowercase(char *input);
